@@ -1,4 +1,4 @@
-pub mod packet {
+pub mod irc {
 
 	//structure for defining irc packets
 	pub struct IrcPacket {
